@@ -1,8 +1,11 @@
+__all__ = "load_config"
+
+
 def load_config(order=None, load=True):
     def decorator(resource):
         if order:
-            resource.load_order = order
-        resource.load_flg = load
+            resource._load_order = order
+        resource._load_flg = load
         return resource
 
     return decorator
